Skip to contents

This method returns the absolute chromosome positions.

Value

A data frame reporting the name (column chr), the length (column length), the initial absolute position (column from), and the final absolute position (column to) of each chromosome.

Details

Its builds a data frame reporting the name, the length, and the initial and final absolute positions of each chromosome in the reference genome.