Getting the cell in which a mutation emerged
Source:R/RcppExports.R
PhylogeneticForest-cash-get_first_occurrences.RdThis method returns the identifier of the cell in which a mutation occurs for the first time.
See also
vignette("mutations") for usage examples