This method returns the nodes of the forest.
Value
A data frame representing, for each node
in the forest, the identified (column cell_id),
whenever the node is not a root, the ancestor
identifier (column ancestor), the node's depth
(column depth), whenever the node was sampled,
i.e., it is one of the forest leaves, the name of
the sample containing the node, (column sample),
the mutant (column mutant), the epistate (column
epistate), and the birth time (column
birth_time).
See also
SampleForest$get_nodes() for usage examples