Skip to contents

This method loads a phylogenetic forest from a file.

Usage

load_phylogenetic_forest(filename)

Arguments

filename

The path of the file from which the phylogenetic forest must be load.

quiet

An optional Boolean flag to avoid the progress bar (default: FALSE).

Value

The load phylogenetic forest